==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/OffsetThrough/ts/OffsetThrough_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineParallelThrough</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk lub okrąg</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="obsolete">Wskaż punkt</translation>
    </message>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation type="obsolete">Liczba:</translation>
    </message>
    <message>
        <source>Par&amp;allel (through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Równolegle (poprzez Point)</translation>
    </message>
    <message>
        <source>Draw parallel line or concentric arc or circle through a given point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rysowanie linii równoległej lub koncentryczne łuk lub okrąg przez dany punkt</translation>
    </message>
</context>
<context>
    <name>OffsetThrough</name>
    <message>
        <location filename="../OffsetThrough.js" line="+67"/>
        <source>Specify point</source>
        <translation type="unfinished">Wskaż punkt</translation>
    </message>
    <message>
        <location filename="../OffsetThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation type="unfinished">Liczba:</translation>
    </message>
    <message>
        <location filename="../OffsetThroughInit.js" line="+2"/>
        <source>Offset (through Point)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse through point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/OffsetThrough/ts/OffsetThrough_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineParallelThrough</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz linię, łuk lub okrąg</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="obsolete">Wskaż punkt</translation>
    </message>
    <message>
        <source>Number:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź liczbę:
Liczba:</translatorcomment>
        <translation type="obsolete">Liczba:</translation>
    </message>
    <message>
        <source>Par&amp;allel (through Point)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Równolegle (poprzez Point)</translation>
    </message>
    <message>
        <source>Draw parallel line or concentric arc or circle through a given point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Rysowanie linii równoległej lub koncentryczne łuk lub okrąg przez dany punkt</translation>
    </message>
</context>
<context>
    <name>OffsetThrough</name>
    <message>
        <location filename="../OffsetThrough.js" line="+67"/>
        <source>Specify point</source>
        <translation>Proszę wskazać punkt</translation>
    </message>
    <message>
        <location filename="../OffsetThrough.ui" line="+17"/>
        <source>Number:</source>
        <translation>Liczba kopii:</translation>
    </message>
    <message>
        <location filename="../OffsetThroughInit.js" line="+2"/>
        <source>Offset (through Point)</source>
        <translation>Odsuń przez punkt</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse through point</source>
        <translation>Odsuwa linię, łuk, okrąg lub elipsę przez punkt</translation>
    </message>
</context>
</TS>
